@@ -12,10 +12,10 @@
 #' containing any \code{FALSE} values) , otherwise it is evaluated in the normal
 #' way and its value will not be checked. If the value of the last
 #' sub-expression is logical, it will also be treated as a test condition.
-#' @param fact a message for the assertions when any of them fails; treated the
+#' @param fact A message for the assertions when any of them fails; treated the
 #'   same way as expressions in \code{...} if it is not a character string,
-#'   which means you do not have to provide a message to this function
-#' @param ... an R expression; see Details
+#'   which means you are not required to provide a message to this function.
+#' @param ... An R expression; see Details.
 #' @return For \code{assert()}, invisible \code{NULL} if all expressions
 #'   returned \code{TRUE}, otherwise an error is signaled and the user-provided
 #'   message is emitted. For \code{\%==\%}, \code{TRUE} or \code{FALSE}.
@@ -32,8 +32,7 @@
 #'   assertions.
 #' @export
 #' @examples
-#' ## The first way to write assertions -------------------
-#'
+#' library(testit)
 #' assert('T is bad for TRUE, and so is F for FALSE', {T=FALSE;F=TRUE
 #' (T!=TRUE)  # note the parentheses
 #' (F!=FALSE)})
@@ -43,30 +42,6 @@
 #' (x >= 0)
 #' (x > -1)  # () is optional because it's the last expression
 #' })
-#'
-#'
-#' ## The second way to write assertions --------------------
-#'
-#' assert('one equals one', 1==1)
-#' assert('seq and : produce equal sequences', seq(1L, 10L) == 1L:10L)
-#' assert('seq and : produce identical sequences', identical(seq(1L, 10L), 1L:10L))
-#'
-#' # multiple tests
-#' T=FALSE; F=TRUE
-#' assert('T is bad for TRUE, and so is F for FALSE', T!=TRUE, F!=FALSE)
-#'
-#' # a mixture of tests
-#' assert("Let's pray all of them will pass", 1==1, 1!=2, letters[4]=='d', rev(rev(letters))==letters)
-#'
-#' # logical(0) cannot pass assert(), although stopifnot() does not care
-#' try(assert('logical(0) cannot pass', 1==integer(0)))
-#' stopifnot(1==integer(0)) # it's OK!
-#'
-#' # a compound expression
-#' try(assert('this if statement returns TRUE', if(TRUE){x=1;x==2}))
-#'
-#' # no message
-#' assert(!FALSE, TRUE, is.na(NA))
 assert = function(fact, ...) {
   opt = options(testit.asserting = TRUE); on.exit(options(opt), add = TRUE)
   mc = match.call()
@@ -188,8 +163,15 @@ test_pkg = function(package, dir = c('testit', 'tests/testit')) {
     detach(pos = i, unload = TRUE, force = TRUE)
 
   library(package, character.only = TRUE)
+
   path = available_dir(c(dir, system.file('tests', 'testit', package = package)))
-  rs = list.files(path, '^test-.+[.][rR]$', full.names = TRUE)
+  fs = list.files(path, full.names = TRUE)
+  # clean up new files/dirs generated during testing
+  if (getOption('testit.cleanup', TRUE)) on.exit({
+    unlink(setdiff(list.files(path, full.names = TRUE), fs), recursive = TRUE)
+  }, add = TRUE)
+  rs = fs[grep('^test-.+[.][rR]$', basename(fs))]
+
   # make all objects in the package visible to tests
   env = new.env(parent = getNamespace(package))
   for (r in rs) {
@@ -197,7 +179,7 @@ test_pkg = function(package, dir = c('testit', 'tests/testit')) {
     withCallingHandlers(
       sys.source2(r, envir = env, top.env = getNamespace(package)),
       error = function(e) {
-        z = .traceback(5)
+        z = tryCatch(.traceback(5), error = function(e) NULL)
         if (length(z) == 0) return()
         z = z[[1]]
         n = length(z)
